# -*- coding: utf-8 -*-
# pylint: disable-msg = C0103, W0612, W0703, E0213
#
# Copyright 2005-2006 André Malo or his licensors, as applicable
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Testcases for svnmailer.notifier.selector

@var _tests: The test classes
@type _tests: C{list}
"""
__author__    = "André Malo"
__docformat__ = "epytext en"
__all__       = ['getSuite']

import unittest
_tests = []


class importTestCase(unittest.TestCase):
    """ Importing svnmailer.notifier.selector """

    def testImport(self):
        """ from svnmailer.notifier import selector """
        try:
            from svnmailer.notifier import selector
        except Exception, exc:
            self.fail(
                "svnmailer.notifier.selector could not be imported: %s" %
                str(exc)
            )

_tests.append(importTestCase)


class SelectorTestCase(unittest.TestCase):
    """ svnmailer.notifier.selector.Selector """

    def setUp(self):
        """ Build test environment """
        from svnmailer.notifier import selector

        self._selector = selector

    def test00selectNotifiers(self):
        """ selectNotifiers returns the proper notifiers list """
        from svnmailer.notifier import mail, news, stdout
        tests = (
            (mail.SendmailSubmitter, {'sendmail_command': True}),
            (mail.SMTPSubmitter, {'smtp_host': True}),
            (news.NNTPSubmitter, {'nntp_host': True}),
            (stdout.StdoutNotifier, {}),
        )

        class mySelector(self._selector.Selector):
            def __init__(this, **kwargs):
                this._settings = Container(
                    general = Container(**kwargs),
                    runtime = Container(is_commit = True),
                )

        for expected, kwargs in tests:
            selector = mySelector(**kwargs)
            result = selector.selectNotifiers(Container(
                groups = [Container()], changes = [], xchanges = []
            ))
            self.failUnless(
                len(result) == 1 and
                result[0].__class__.__name__ == expected.__name__,
                "Expected %r, got %r" % (expected, result)
            )

_tests.append(SelectorTestCase)


class Container(object):
    def __init__(this, **kwargs):
        this._dict = kwargs
    def __getattr__(this, name):
        return this._dict.get(name)


#### Glue code                                      ####
########################################################
__all__.extend(_tests)

def getSuite():
    """ Returns the test suite for this module """
    return unittest.TestSuite([
        unittest.makeSuite(test) for test in _tests
    ])

if __name__ == '__main__':
    unittest.TextTestRunner(verbosity = 2).run(getSuite())
